require 'spec_helper'

describe Ladyboy::Parser do
  it do
    example = Ladyboy::Parser.new 'Петр'
    example.first_name.must_equal 'Петр'
    example.gender.must_equal     :male
    example.sex.must_equal        :male    # alias to gender

    example = Ladyboy::Parser.new 'Оля'
    example.first_name.must_equal 'Ольга'
    example.gender.must_equal     :female

    example = Ladyboy::Parser.new 'zhenya'
    example.first_name.must_equal 'Женя'
    example.gender.must_equal     nil      # unisex

    example = Ladyboy::Parser.new 'Саша'
    example.first_name.must_equal 'Саша'
    example.gender.must_equal     nil

    example = Ladyboy::Parser.new 'Рамзанкадыров'
    example.first_name.must_equal nil
    example.gender.must_equal     nil

    example = Ladyboy::Parser.new 'пётр, Абулгары  Эрнест '
    example.first_name.must_equal 'Петр'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new 'Абулгары  Эрнест!'
    example.first_name.must_equal 'Эрнест'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new 'Пётр, Абулгары Наташа!'
    example.first_name.must_equal 'Петр'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new 'Наташа Пётр, Абулгары!'
    example.first_name.must_equal 'Наталья'
    example.gender.must_equal     :female

    example = Ladyboy::Parser.new 'Рамзанкадыров Тут Проходил'
    example.first_name.must_equal nil
    example.gender.must_equal     nil

    example = Ladyboy::Parser.new 'vasya1985@mail.ru'
    example.first_name.must_equal 'Василий'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new 'kolya.petrov@google.com'
    example.first_name.must_equal 'Николай'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new 'olga.petrov@yandex.ru'
    example.first_name.must_equal 'Ольга'
    example.gender.must_equal     :female

    example = Ladyboy::Parser.new 'dark.imperior@live.com'
    example.first_name.must_equal nil
    example.gender.must_equal     nil

    example = Ladyboy::Parser.new 'Jesus'
    example.first_name.must_equal 'Jesus'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new 'Buendia Francisco Javier'
    example.first_name.must_equal 'Francisco Javier'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new 'Kilian Byszio'
    example.first_name.must_equal 'Килиан'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new 'César Hernández'
    example.first_name.must_equal 'Cesar'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new 'Mayte Nogales Martin'
    example.first_name.must_equal 'Mayte'
    example.gender.must_equal     :female

    example = Ladyboy::Parser.new 'Paula San Gregorio'
    example.first_name.must_equal 'Paula'
    example.gender.must_equal     :female

    example = Ladyboy::Parser.new 'ENRIC VILA SAGUE'
    example.first_name.must_equal 'Enric'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new 'Jose Maria de la Peña'
    example.first_name.must_equal 'Jose Maria'
    example.gender.must_equal     :male

    example = Ladyboy::Parser.new nil
    example.first_name.must_equal nil
    example.gender.must_equal     nil

    [["Daniel", :female],
    ["Mayte Nogales", :male],
    ["Andrea", :male],
    ["Jesús Rosa Lázaro", :female],
    ["Patricia", :male],
    ["Andrea", :male],
    ["ENRIC VILA SAGUE", :female],
    ["Andrea", :male],
    ["andrea sanchez gadea", :male],
    ["Patricia", :male],
    ["BELÉN", :male],
    ["Mohamed", :female],
    ["Rodrigo Crespo", :female],
    ["Jose Maria de la Peña", :female],
    ["Belen", :male],
    ["Jose Maria", :female],
    ["Carmen", :male],
    ["Andrea", :male],
    ["Carmen", :male],
    ["Andrea", :male],
    ["guillermo tamayo", :female],
    ["Carmen", :male],
    ["Alejandro", :female],
    ["alberto", :female],
    ["Belén Baztan", :male],
    ["Andrea", :male],
    ["Carmen", :male],
    ["ari", :male],
    ["Patricia", :male],
    ["carol", :male],
    ["carmen", :male],
    ["Inma Vidal", :male],
    ["Alba franco", :male],
    ["Carmen", :male],
    ["carmen", :male],
    ["cristina ferrandiz clemente", :male],
    ["Carmen", :male],
    ["Paola marin", :male],
    ["Génesis", :male],
    ["Andrea López villalba", :male],
    ["Carmen", :male],
    ["Guadalupe", :male],
    ["M carmen", :male],
    ["Andrea", :male],
    ["belen", :male],
    ["Miriam alonso civera", :male],
    ["Victoria", :male],
    ["Pilar", :male],
    ["Patricia", :male],
    ["Cristina Lorenzo", :male],
    ["Teresa García- Roca", :male],
    ["Andrea Roca", :male]].each do |name, sex|
      example = Ladyboy::Parser.new name
      [name, example.gender].must_equal     [name, {male: :female, female: :male}[sex]]
    end
    [
      ["Azulema", :female],
      ["Mariuxi Navarrete", :female],
      ["Rubsay Azócar", :female],
      ["Mariate", :male],
      ["Arenosky", :male],
      ["Stef", :female],
      ["Rodri", :male],
      ["Sofía", :female],
      ["Sofía", :female],
      ["Anhara", :female],
      ["Fer", :male],
      ["Guille", :male],
      ["Zhuraida", :female],
      ["Yayo Garrido Gómez", :male],
      ["Muels", :male],
      ["Luis blazquez lizan", :male],
      ["Luis Blazquez Lizan", :male],
      ["Pilar", :female],
      ["Elia", :female],
      ["Fernando", :male],
      ["Carlos", :male],
      ["Pablo ", :male],
      ["Inés Tardy", :female],
      ["Pablo Judez", :male],
      ["Carolina Borrajo Yusty", :female],
      ["Begoña", :female],
      ["Mer", :female],
      ["Guille", :male],
      ["Yaya", :male],
      ["Ricky", :male],
      ["Yago", :male],
      ["Noèlia", :female],
      ["Cris", :female],
      ["Eulogio", :male],
      ["Pablo", :male],
      ["Diarmuid", :male],
      ["Diarmuid", :male],
      ["Blanca Leach", :female],
      ["Teresa", :female],
      ["Almudena", :female],
      ["pau llorca", :male],
      ["Rodrigo", :male],
      ["Nuria", :female],
      ["Ángel", :male],
      ["Juancho", :male],
      ["rafaverguis", :male],
      ["Almudena", :female],
      ["Alejandro", :male],
      ["Santiago Vázquez", :male],
      ["Anabel", :female],
      ["Javila", :male],
      ["teresa", :female],
      ["Sofia Herrera", :female],
      ["Manuel Esparza", :male],
      ["iciar", :female],
      ["Fernando", :male],
      ["Alberto", :male],
      ["Ignacio ", :male]].each do |name, sex|
      example = Ladyboy::Parser.new name
      [name, example.gender].must_equal     [name, sex]
    end

    [["ana", :female],
      ["Elisa", :female],
      ["Germán", :male],
      ["Alberto", :male],
      ["Elvira", :female],
      ["toti", nil],
      ["Santi", :male],
      ["Bosco", :male],
      ["Cristina", :female],
      ["Ignacio", :male],
      ["David", :male],
      ["david", :male],
      ["Josemaría Albaladejo", :male],
      ["Diego", :male],
      ["Maria", :female],
      ["Luis blazquez", :male],
      ["Luis", :male],
      ["Andrea Roca", :female],
      ["Alfonso de medina", :male],
      ["Enrique García-Chamón Boronat", :male],
      ["fabianaco", :male],
      ["Ignacio Fernández-Montes Andreu", :male],
      ["Alvaro Cobas Bravo", :male],
      ["mohamed ouass", :male],
      ["Paula", :female],
      ["Sara", :female],
      ["Juan Luis", :male],
      ["María Laura", :female],
      ["María Rosa Clavero", :female],
      ["Nacho", :male],
      ["Ignacio mendez richard", :male],
      ["Álvaro López", :male],
      ["nacho diez", :male],
      ["Ignacio", :male],
      ["Juan", :male],
      ["Rosa Maria", :female],
      ["Belen", :female],
      ["María", :female],
      ["maria rojas", :female],
      ["Luis", :male],
      ["Jose Ignacio", :male],
      ["maria", :female],
      ["Blanca", :female],
      ["Beatriz Petit", :female],
      ["Ane", :female],
      ["Mares Castillo", :female],
      ["Daniel", :male],
      ["Marian González", :female],
      ["María del Mar", :female],
      ["Aida Burgos", :female],
      ["María Buades Criado", :female],
      ["Alvaro", :male],
      ["Alejandro Romero Bellido", :male],
      ["Seldelacarrera", nil],
      ["Alejandro Navas", :male],
      ["elena", :female],
      ["Isabel", :female],
      ["nacho lopez navarro", :male],
      ["ignacio", :male],
      ["Sergio", :male],
      ["Emilio morillo morillo", :male],
      ["Paula San Gregorio", :female],
      ["alex", :male],
      ["Alejandro", :male],
      ["Perico", :male],
      ["Pablo", :male],
      ["Roque", :male],
      ["Angela", :female],
      ["rocio", :female],
      ["DANIEL", :male],
      ["Menchu Sanchez Moraga", :female],
      ["blanca de la vega", :female],
      ["Laura", :female],
      ["Diego", :male],
      ["Ana", :female],
      ["Víctor", :male],
      ["Silfer", :female],
      ["Maria", :female],
      ["Jaime", :male],
      ["Fernando", :male],
      ["Esther Lorente", :female],
      ["Alberto de la Escalera Díaz", :male],
      ["MARTA", :female],
      ["Andrea González", :female],
      ["almudena aguiar", :female],
      ["Fradesh", nil],
      ["carolina raynaud", :female],
      ["Maria", :female],
      ["carmen andrades linares", :female],
      ["laura", :female],
      ["Blanca", :female],
      ["Jose Manuel", :male],
      ["jaime", :male],
      ["adria pinto", :male],
      ["Juan", :male],
      ["sofia", :female],
      ["Pilar Soto Gavaldà", :female],
      ["Irene", :female],
      ["Marina", :female],
      ["Inmaculada", :female],
      ["alberto", :male],
      ["dave", :male],
      ["María", :female],
      ["rafa alonso linares", :male],
      ["Nacho", :male],
      ["Laura Martos", :female],
      ["jorge", :male],
      ["ana", :female],
      ["ANABEL", :female],
      ["Alvaro", :male],
      ["Jorge Rivas", :male],
      ["Inmaculada", :female],
      ["jorge traba", :male],
      ["Pedro Arraiza", :male],
      ["Jorge masot Cardenal", :male],
      ["anamorasanchis", nil],
      ["Roxana", :female],
      ["Irene Fernández-Rivera", :female],
      ["Patricia", :female],
      ["Almudena", :female],
      ["Almudena", :female],
      ["Loreto Glez-Montagut", :female],
      ["celia", :female],
      ["Carmen  Aranda", :female],
      ["Juanma romero", :male],
      ["Almudena", :female],
      ["Sonia Puig", :female],
      ["Lucía", :female],
      ["Pablo", :male],
      ["Gaspar Quiles", :male],
      ["David", :male],
      ["Javier", :male],
      ["Esperanza Moreno Perez", :female],
      ["Marieta Bielsa", :female],
      ["Juan", :male],
      ["pablo", :male],
      ["ignacio", :male],
      ["Clara", :female],
      ["Belén", :female],
      ["Laura", :female],
      ["lucia", :female],
      ["Claudia", :female],
      ["juan", :male],
      ["Juancho", :male],
      ["Monica galache", :female],
      ["Guillermo González Ananín", :male],
      ["Beatriz", :female],
      ["ROCIO", :female],
      ["Mari Carmen", :female],
      ["Ana", :female],
      ["Macarena de la Haza", :female],
      ["Isabel Ortiz", :female],
      ["julia", :female],
      ["María Jesús", :female],
      ["Mila", :female],
      ["Yaiza", :female],
      ["Alba", :female],
      ["ferran albert", :male],
      ["Helena Artola", :female],
      ["Nicolas Ruiz", :male],
      ["Dani", :male],
      ["Carmen Moyano", :female],
      ["Ana del Rio Oliva", :female],
      ["María", :female],
      ["Alvaro Jimenez Molina", :male],
      ["concha Hernández", :female],
      ["Maria Infante", :female],
      ["Angela Marrugal", :female],
      ["antonio Gil", :male],
      ["Pau", :male],
      ["Andrea", :female],
      ["Laura", :female],
      ["Isabel M. García Martínez", :female],
      ["Marta", :female],
      ["marcos", :male],
      ["Fatima Barrera", :female],
      ["Javier Apaolaza", :male],
      ["Enrique Álvarez", :male],
      ["luisa", :female],
      ["Damián", :male],
      ["Julia Parias", :female],
      ["Elena", :female],
      ["Laura", :female],
      ["Pablo serrano Gomez", :male],
      ["Miriam", :female],
      ["ricardo", :male],
      ["Juan", :male],
      ["Antonio Hidalgo García", :male],
      ["Nuria", :female],
      ["Elena", :female],
      ["alessandra", :female],
      ["pablo bellot esteve", :male],
      ["juanjo del valle", :male],
      ["Álvaro Serra", :male],
      ["Elena", :female],
      ["Fernando Saugar", :male],
      ["Paula López", :female],
      ["Maria Yáñez", :female],
      ["Jorge", :male],
      ["ana", :female],
      ["iñigo marin", :male],
      ["Concha Añón Gisbert", :female],
      ["edugelpi", :male],
      ["Ana", :female],
      ["Miguel Angel Moreno", :male],
      ["david", :male],
      ["Alejandro Samaniego Jurado", :male],
      ["Kathy Rico", :female],
      ["alvaro", :male],
      ["Susana", :female],
      ["Adriana", :female],
      ["Marta Figueroa", :female],
      ["Montse  Pauner", :female],
      ["pablo", :male],
      ["NATALIA", :female],
      ["julia", :female],
      ["Marta Segura Medina", :female],
      ["Cristina Carreño", :female],
      ["Angela", :female],
      ["albi", :female],
      ["Blanca Ugarte", :female],
      ["Hugo", :male],
      ["Diego", :male],
      ["Daniel Gonzalez", :male],
      ["Armando", :male],
      [" Hugo Souviron", :male],
      ["Inés", :female],
      ["Poul Nissen", :male],
      ["Natalia", :female],
      ["Nika Alonso", :female],
      ["Julia", :female],
      ["Teresa", :female],
      ["Carla Samper", :female],
      ["estrella", :female],
      ["Nika", :female],
      ["Ana", :female],
      ["JAvier", :male],
      ["Maria obando", :female],
      ["Rafael Martin-Lomeña", :male],
      ["Adolfo", :male],
      ["Carolina", :female],
      ["Eider", :male],
      ["Maria", :female],
      ["Carmen", :female],
      ["Angela", :female],
      ["Juanpauc", :male],
      ["Monica", :female],
      ["Alicia", :female],
      ["Diego", :male],
      ["José Ramón Fernández Acosta", :male],
      ["Aida", :female],
      ["Elisa Selgas", :female],
      ["Sara bobillo moratinos", :female],
      ["Angeles", :female],
      ["Pol", :male],
      ["óscar", :male],
      ["Maria Arraga", :female],
      ["Andrea", :female],
      ["Aurora", :female],
      ["Teresa", :female],
      ["Júlia Monte", :female],
      ["Andrea", :female],
      ["Enrique", :male],
      ["Alberto Gundin Lorenzo", :male],
      ["Alejandro", :male],
      ["bartolome", :male],
      ["Carlos", :male],
      ["angela caro morales", :female],
      ["Isabel", :female],
      ["Esther Gomez", :female],
      ["Jose Ignacio", :male],
      ["Maria", :female],
      ["Antonio", :male],
      ["nuria miguel berdiel", :female],
      ["María", :female],
      ["Blanca Gonzalez", :female],
      ["miguel", :male],
      ["ANE", :female],
      ["Alejandra", :female],
      ["Laura", :female],
      ["Jorge", :male],
      ["Ines rodriguez", :female],
      ["macarena", :female],
      ["Blanca González", :female],
      ["Hugo", :male],
      ["Candela Glez", :female],
      ["Yago", :male],
      ["Maria", :female],
      ["Ileana", :female],
      ["Javi fernandez", :male],
      ["Maria", :female],
      ["Maria eugenia", :female],
      ["Alfonso", :male],
      ["Marta", :female],
      ["Lucía", :female],
      ["Fernando", :male],
      ["Irene Centeno", :female],
      ["Jesús Pazos", :male],
      ["Juan carlos", :male],
      ["Jaime  reinoso", :male],
      ["María", :female],
      ["MARIA", :female],
      ["Mariana Acedo", :female],
      ["Fernando Prieto Soria", :male],
      ["hache", nil],
      ["Pablo Caneda Gonzalez", :male],
      ["Violeta", :female],
      ["Ana", :female],
      ["Mencia", :female],
      ["teresa", :female],
      ["Juan Manuel", :male],
      ["María", :female],
      ["Magdalena de la Linde Palomino", :female],
      ["Aida", :female],
      ["jesus vega", :male],
      ["Carlota García Miralles", :female],
      ["olga nuñez rodriguez", :female],
      ["Miriam", :female],
      ["Pablo Mencía", :male],
      ["cristina", :female],
      ["Isabel", :female],
      ["Lorena", :female],
      ["Paula", :female],
      ["Gonzalo", :male],
      ["Susana Fernández", :female],
      ["Tere", :female],
      ["DOLORES ESPINO PEREZ", :female],
      ["Andrés Gómez Rubio", :male],
      ["Inma", :female],
      ["Celia", :female],
      ["Manolo Fernández Gálvez", :male],
      ["Elena", :female],
      ["Raquel", :female],
      ["Alvaro", :male],
      ["Paula", :female],
      ["Teresa", :female],
      ["Adela", :female],
      ["Pilar", :female],
      ["Lucia", :female],
      ["Rmb", nil],
      ["Concha", :female],
      ["Sara", :female],
      ["Cristina", :female],
      [" Sonia gonzález", :female],
      ["Carlos", :male],
      ["Carlos", :male],
      ["Andrea", :female],
      ["Marta", :female],
      ["Maria Álvarez-Rementería", :female],
      ["isabel", :female],
      ["maite", :female],
      ["MARTA", :female],
      ["juan luis", :male],
      ["Ignacio", :male],
      ["Laura quiles", :female],
      ["Regina", :female],
      ["susana", :female],
      ["Carlota", :female],
      ["Almudena", :female],
      ["Javier", :male],
      ["ANA PASTOR", :female],
      ["Jessica", :female],
      ["Mamadou diallo", :male],
      ["Beatriz lizarriturri", :female],
      ["Guillermo martin", :male],
      ["Claudia", :female],
      ["Cristina", :female],
      ["Adriana Lacueva", :female],
      ["Marcos", :male],
      ["Santi", :male],
      ["María", :female],
      ["Iago", :male],
      ["Ana Vázquez", :female],
      ["Luis Garcia", :male],
      ["Ni", nil],
      ["Paula", :female],
      ["Juan Garcia de Solis", :male],
      ["Carmen alonso", :female],
      ["Carlos Guitart", :male],
      ["Mar", :female],
      ["Carlos sanch", :male],
      ["amaia", :female],
      ["Álvaro", :male],
      ["Lucia Ybarra", :female],
      ["Ayoub", :male],
      ["isabel", :female],
      ["Ricardo", :male],
      ["Nima", :male],
      ["Loreto", :female],
      ["gemma", :female],
      ["Carolina", :female],
      ["Javier Amorín", :male],
      ["Gonzalo Marquínez", :male],
      ["Oscar rodriguez", :male],
      ["Marisol", :female],
      ["Guillerm", :male],
      ["Annabel Coutou", :female],
      ["andrea comba", :female],
      ["Alex Boxall", :male],
      ["Sedki jemmali", :male],
      ["rodrigo laorden", :male],
      ["Marta", :female],
      ["sebastian", :male],
      ["Jose carlos", :male],
      ["Monica", :female],
      ["Marina", :female],
      ["Emilia", :female],
      ["Gracia Bañon", :female],
      ["sebastian", :male],
      ["Pilar", :female],
      ["Carmen", :female],
      ["Ye", :male],
      ["CARLOS PM", :male],
      ["MARTA", :female],
      ["Laura Domínguez-Adame", :female],
      ["Míriam alfageme", :female],
      ["Pablo  Díaz Cerezuela", :male],
      ["Francisca", :female],
      ["Pablo", :male],
      ["Salwa", :female],
      ["Santi", :male],
      ["maria victoria valcarcel marin", :female],
      ["natalia", :female],
      ["Rocio noguera", :female],
      ["francisco garcía", :male],
      ["magda", :female],
      ["Jaime Ferrandiz Gutierrez", :male],
      ["mercedes", :female],
      ["Román", :male],
      ["Yerina", :female],
      ["Silvia González Atienza", :female],
      ["Alba", :female],
      ["Teresa", :female],
      ["Maria Braco", :female],
      ["Pablo Heydt", :male],
      ["Eugenia Sanle", :female],
      ["Jose Luis Romero Rufo", :male],
      ["Miriam", :female],
      ["Candela", :female],
      ["Pablo Ibáñez", :male],
      ["Carlos", :male],
      ["Antonio Valverde Bascón", :male],
      ["Borja", :male],
      ["Maria", :female],
      ["Maitane Feced", :female],
      ["Manuel", :male],
      ["Maria Cruz", :female],
      ["Blanca núñez", :female],
      ["Laura", :female],
      ["Susana gonzalez", :female],
      ["Alicia", :female],
      ["José Manuel", :male],
      ["Guillermo", :male],
      ["Amelia Melión", :female],
      ["Test 123 Arenillas", nil],
      ["Maria", :female],
      ["NACHO", :male],
      ["Fernando", :male],
      ["cuca ascaso", :female],
      ["Paloma gangoso", :female],
      ["Maria Martin Gutierrez", :female],
      ["Lali", :female],
      ["Laura", :female],
      ["Juan andres", :male],
      ["Sonsoles", :female],
      ["Carmen Alonso garcia", :female],
      ["Marta", :female],
      ["Mariana", :female],
      ["Pablo", :male],
      ["Angela", :female],
      ["José María Briones Serrano", :male],
      ["Paula", :female],
      ["De castro", :male],
      ["montse", :female],
      ["Alba Olivares Guerrero", :female],
      ["Guille", :male],
      ["María", :female],
      ["Manuel Zafra", :male],
      ["Genara", :female],
      ["Elena", :female],
      ["Mayte", :female],
      ["Fran Moreno Gomez", :male],
      ["Alba", :female],
      ["Carmen", :female],
      ["Yago Gorriz", :male],
      ["mikele", :male],
      ["Manuel", :male],
      ["Carlos", :male],
      ["Connie", :female],
      ["Luis", :male],
      ["María José Ramiro", :female],
      ["Elena", :female],
      ["Gonzalo López Sanz", :male],
      ["María", :female],
      ["vari", nil],
      ["Jose María Alfaro", :male],
      ["José Raúl Martínez", :male],
      ["Isabel", :female],
      ["MANUEL", :male],
      ["alvaro jimenez", :male],
      ["Pati Topham", :female],
      ["Carlota", :female],
      ["Clara", :female],
      ["Carlota", :female],
      ["yasmina", :female],
      ["Javier Iglesias", :male],
      ["Hugo", :male],
      ["Tomás Emilio", :male],
      ["silvia", :female],
      ["silvia", :female],
      ["Almudena Rielo Losantos", :female],
      ["Paula", :female],
      ["Diego", :male],
      ["Palomadejuann", nil],
      ["Mercedes Senent", :female],
      ["Ricardo Torres", :male],
      ["Adriana", :female],
      ["Elena", :female],
      ["Victor Mohedano", :male],
      ["Nacho", :male],
      ["jara", :female],
      ["Micaela", :female],
      ["Idania Toledo", :female],
      ["Beatriz", :female],
      ["JUAN", :male],
      ["Lidia", :female],
      ["beatriz", :female],
      ["Pepe González matud", :male],
      ["Cristina", :female],
      ["rocio", :female],
      ["Joel Rodriguez", :male],
      ["Silvi del saz", :female],
      ["Andrea Frial Selas", :female],
      ["Pedro", :male],
      ["Roberto", :male],
      ["Maria Bernal", :female],
      ["Javier Tabares", :male],
      ["Borja", :male],
      ["claudia", :female],
      ["Marian Sanromán Gómez", :female],
      ["Juan", :male],
      ["Paloma Martín Gómez", :female],
      ["Pedro de Torres", :male],
      ["Herman", :male],
      ["Juan", :male],
      ["blanca", :female],
      ["jaime", :male],
      ["Blanca", :female],
      ["Paula", :female],
      ["Miguel", :male],
      ["Rubén Buitrago Peña", :male],
      ["María", :female],
      ["Victoria", :female],
      ["Jesus Olmedilla", :male],
      ["Guadalupe", :female],
      ["cruz", :male],
      ["Maria josefa", :female],
      ["Andrea Sanchez✌🏽️", :female],
      ["María Nemesio", :female],
      ["José", :male],
      ["pablo", :male],
      ["Daniella", :female],
      ["joaquin albacar", :male],
      ["Marina", :female],
      ["Paula", :female],
      ["jose", :male],
      ["carlota", :female],
      ["Leire", :female],
      ["Myriam Gil", :female],
      ["Paloma bang", :female],
      ["BEATRIZ MIRON", :female],
      ["Blanca Kirkendall", :female],
      ["Darío", :male],
      ["Jorge vazquez", :male],
      ["Paulino", :female],
      ["Sergio", :male],
      ["Manuel Díaz Santana", :male],
      ["María", :female],
      ["Nicoleta", :female],
      ["jose manuel", :male],
      ["Trini", :female],
      ["Raúl", :male],
      ["sara sanchez ramos", :female],
      ["Teresa", :female],
      ["John", :male],
      ["Karen", :female],
      ["Pierre", :male],
      ["Belen Reina", :female],
      ["Marta Sebastia", :female],
      ["Charo", :female],
      ["Patricia", :female],
      ["M.dolores Martinez-Corbalan Campillo", :female],
      ["tyua", nil],
      ["Ignacio", :male],
      ["Vera", :female],
      ["Carmen Godoy ordoñez", :female],
      ["Araceli", :female],
      ["Pol", :male],
      ["Javier Rodríguez Martinez", :male],
      ["Darián", :male],
      ["Marcos", :male],
      ["Sofia Zaballa", :female],
      ["Mario", :male],
      ["Ana", :female],
      ["Jose Antonio Deus", :male],
      ["Lauuii", :female],
      ["Juan", :male],
      ["Alvaro", :male],
      ["Marta", :female],
      ["Nuria", :female],
      ["fernandohdezr", nil],
      ["Jhóselin", :female],
      ["María Rojas", :female],
      ["Mercedes cervera", :female],
      ["Jaime", :male],
      ["María", :female],
      ["Víctor David Resurrección", :male],
      ["Sandra", :female],
      ["Efren", :male],
      ["Miguel angel", :male],
      ["Rafa", :male],
      ["Ana Vallejo Basanta", :female],
      ["Miriam Vizcaino parias", :female],
      ["Pablo Trigo", :male],
      ["Alberto", :male],
      ["Daniel Velasquez", :male],
      ["Manu", :male],
      ["Jessica", :female],
      ["MARIAN COGOLLOS PAJA", :female],
      ["Enrique alonso robles", :male],
      ["Tania", :female],
      ["Javier", :male],
      ["Miguel", :male],
      ["Miguel", :male],
      ["Javier González", :male],
      ["Irene Rodríguez", :female],
      ["Irina Heras Fraga", :female],
      ["David sabiote navarro", :male],
      ["lucia", :female],
      ["Vicente Fort", :male],
      ["Sherry", :female],
      ["Nacho Martin", :male],
      ["Lara Agustina", :female],
      ["Reyes Martínez galan", :female],
      ["Alfredo", :male],
      ["Alfonso Hidalgo", :male],
      ["Lucía", :female],
      ["Belen", :female],
      ["Keyko Okubo", :male],
      ["Patricia", :female],
      ["marta", :female],
      ["Constanza Pedroche", :female],
      ["Oscar", :male],
      ["Ana", :female],
      ["Marta Bellés", :female],
      ["Alvaro Pérez", :male],
      ["Julián", :male],
      ["pablo ayuso llorente", :male],
      ["Isaac", :male],
      ["javiermpicabea", nil],
      ["Ana Domingo Sierra", :female],
      ["Alicia", :female],
      ["Leire", :female],
      ["Eduardo Galindo Pérez", :male],
      ["amparo", :female],
      ["Ivan", :male],
      ["Enrique", :male],
      ["maria jesus fernandez velarde", :female],
      ["Belén Gonzalo", :female],
      ["cristina", :female],
      ["Isabel haurie lara", :female],
      ["Javier", :male],
      ["Esperanza Moreno Perez", :female],
      ["Joselin", :male],
      ["Beatriz", :female],
      ["Ana López Maraver", :female],
      ["Lucas Zabala", :male],
      ["Adrián", :male],
      ["Juan Jesús", :male],
      ["Rafa Antuña", :male],
      ["Juan antonio", :male],
      ["José luis", :male],
      ["Carlos", :male],
      ["Antonio", :male],
      ["Miriam", :female],
      ["alejandro laseca", :male],
      ["Anna", :female],
      ["Beatriz", :female],
      ["Mercedes", :female],
      ["LAURA", :female],
      ["Domènec Melé", :male],
      ["Begoña", :female],
      ["Yago", :male],
      ["INÉS", :female],
      ["Gonzalo", :male],
      ["Daniel Garcia", :male],
      ["Nico", :male],
      ["jaime", :male],
      ["PAULA", :female],
      ["Alejandro", :male],
      ["Giulia G.", :female],
      ["Manu", :male],
      ["Javier Corcuera", :male],
      ["Encarna", :female],
      ["Antonio", :male],
      ["Javier", :male],
      ["Montse", :female],
      ["Conchita", :female],
      ["Laura Andrés", :female],
      ["javier", :male],
      ["Ignacio Velasco", :male],
      ["Alberto ortigosa", :male],
      ["OLGA", :female],
      ["Manolo", :male],
      ["Clara", :female],
      ["Begoña", :female],
      ["Alejandro Álvarez", :male],
      ["Bamija", :female],
      ["Javier", :male],
      ["Jhon González González", :male],
      ["Maria", :female],
      ["Beatriz gómez de Olea", :female],
      ["Antonia", :female],
      ["vera", :female],
      ["Loreto", :female],
      ["Fran", :male],
      ["Pilar Martín", :female],
      ["Paula Emperador", :female],
      ["javier moreno", :male],
      ["Maria", :female],
      ["Samuel ruiz", :male],
      ["María Barril", :female],
      ["Javier", :male],
      ["Gonzalo Cabeza", :male],
      ["Yago", :male],
      ["Raquel sacristán", :female],
      ["Alejandra", :female],
      ["Juanjo", :male],
      ["Thais", :female],
      ["German", :male],
      ["Lucía", :female],
      ["maria jose lucas guerrero", :female],
      ["Silvia", :female],
      ["jaime", :male],
      ["Ivan", :male],
      ["Maria", :female],
      ["Christian", :male],
      ["Marta", :female],
      ["fran", :male],
      ["Juan", :male],
      ["Lucia resino", :female],
      ["Inigo", :male],
      ["carmen", :female],
      ["Aida Conejero Adsuara", :female],
      ["Maria Eugenia Autran", :female],
      ["Cristina", :female],
      ["Patricia", :female],
      ["Carlos", :male],
      ["Jorge vazquez", :male],
      ["Ana romero", :female],
      ["Jesus", :male],
      ["Ana Navedo", :female],
      ["alberto", :male],
      ["Fernando", :male],
      ["Amalia martin", :female],
      ["Alejandro Gonzalez Iguacen", :male],
      ["Álvaro Canosa Pascual", :male],
      ["Virtudes ruiz", :female],
      ["Nicolás", :male],
      ["Gema alonso", :female],
      ["Irene Da Costa", :female],
      ["María Bolívar", :female],
      ["pilar", :female],
      ["daphne", :female],
      ["Andrea Fernández", :female],
      ["Belén", :female],
      ["Rosa", :female],
      ["alvaro", :male],
      ["Jimena", :female],
      ["Ana", :female],
      ["Belén", :female],
      ["Carola", :female],
      ["Ana Pérez-Lozana", :female],
      ["Paula García-Hirschfeld", :female],
      ["Pablo Villanueva", :male],
      ["rocio", :female],
      ["Marta", :female],
      ["Paula", :female],
      ["david", :male],
      ["Jaime Alba", :male],
      ["Almudena de lama", :female],
      ["Pablo Aparicio", :male],
      ["Javier Gardon", :male],
      ["Nacho", :male],
      ["Antonio Núñez", :male],
      ["Rocío Hernandez", :female],
      ["Miguel Ángel Ágreda Rico", :male],
      ["victoria", :female],
      ["Teresa", :female],
      ["Sergio", :male],
      ["Silvia", :female],
      ["catalinag", :female],
      ["Alba", :female],
      ["Celia garcía", :female],
      ["Concha Martínez galan", :female],
      ["Bea", :female],
      ["maria", :female],
      ["Jorge iglesias", :male],
      ["Juancho", :male],
      ["Carmen", :female],
      ["Tristan", :male],
      ["natalia", :female],
      ["Beatriz", :female],
      ["Cristina", :female],
      ["Sofia Mijan", :female],
      ["mariags", nil],
      ["Pablo", :male],
      ["Andrea", :female],
      ["Maite", :female],
      ["Cayetano romero", :male],
      ["miguel", :male],
      ["lucas", :male],
      ["José Antonio", :male],
      ["Emilio de la Torriente", :male],
      ["Olga Martinez", :female],
      ["Ignacio morales", :male],
      ["María Sánchez de León", :female],
      ["Candela", :female],
      ["Victor Manuel", :male],
      ["Miguel angel", :male],
      ["Javier", :male],
      ["Nacho", :male],
      ["Lucia Mejía", :female],
      ["Lucia", :female],
      ["Pilar", :female],
      ["borja nieto", :male],
      ["Didier Virey Alcaide", :male],
      ["Macarena", :female],
      ["ricardo", :male],
      ["Belen", :female],
      ["gabi", :male],
      ["Sofia", :female],
      ["nacho lopez navarro", :male],
      ["Belen escribano", :female],
      ["robertojimenezj@hotmail.com", nil],
      ["Marina", :female],
      ["Carmen", :female],
      ["JAVIER", :male],
      ["Javier Iglesias", :male],
      ["Luisa sousa", :female],
      ["Eva del rey", :female],
      ["Mariluz Bellon", :female],
      ["Sara", :female],
      ["Laura", :female],
      ["Alessandra Vignozzi", :female],
      ["Elena Delgado González", :female],
      ["Lucia", :female],
      ["Carlos", :male],
      ["Jesus", :male],
      ["monica", :female],
      ["Alejandra", :female],
      ["Iciar Garcia Joga", :female],
      ["Antonio", :male],
      ["Laura", :female],
      ["Sofia", :female],
      ["Monica", :female],
      ["Gontzal", :male],
      ["Iñigo", :male],
      ["jose.dedios", :male],
      ["Clara López", :female],
      ["Belen", :female],
      ["carlota", :female],
      ["Araceli", :female],
      ["Sandra", :female],
      ["Rocío", :female],
      ["David", :male],
      ["Sofia", :female],
      ["Joan Marín", :male],
      ["Óscar", :male],
      ["Laura", :female],
      ["Arturo", :male],
      ["javier", :male],
      ["Alberto Muriel", :male],
      ["Atonoli", :male],
      ["NATALIA DE MARCOS RAMIREZ", :female],
      ["manu", :male],
      ["Juan", :male],
      ["Alicia Fernández Muñiz", :female],
      ["Monse", :female],
      ["Maria", :female],
      ["Raquel", :female],
      ["Jose", :male],
      ["Marta curado", :female],
      ["ana", :female],
      ["David", :male],
      ["Santiago", :male],
      ["María", :female],
      ["Almudena Tornero", :female],
      ["Alex", :male],
      ["María del Carmen", :female],
      ["Carla", :female],
      ["Marta Magaña", :female],
      ["Manuel", :male],
      ["Leticia", :female],
      ["Cristina", :female],
      ["Carmen", :female],
      ["Alberto", :male],
      ["ignacio", :male],
      ["maria serrano", :female],
      ["Manuel", :male],
      ["Catalina", :female],
      ["Olga", :female],
      ["Xavi", :male],
      ["Fernando", :male],
      ["Carlos Gómez Gil", :male],
      ["Marta", :female],
      ["María", :female],
      ["Guzman", :male],
      ["Irene", :female],
      ["Maria", :female],
      ["Cristina pizarro", :female],
      ["Javier", :male],
      ["Sanjay", :male],
      ["Luisa", :female],
      ["Diana", :female],
      ["Luis Paquet García", :male],
      ["Julia", :female],
      ["AlexB", nil],
      ["Miguel", :male],
      ["ac.maria", :female],
      ["Pablo García", :male],
      ["Xavi", :male],
      ["Aitor", :male],
      ["Ruben", :male],
      ["Sofia", :female],
      ["ana", :female],
      ["alex", :male],
      ["Miguel", :male],
      ["Enrique", :male],
      ["CLAUDIA TORTOLA", :female],
      ["guille", :male],
      ["Rafa Escrich", :male],
      ["Javier", :male],
      ["Javier", :male],
      ["Santiago Latorre", :male],
      ["eliashadjeres", nil],
      ["Alejandro", :male],
      ["Maria", :female],
      ["Sonsoles", :female],
      ["Julia Álvarez Reguera", :female],
      ["Alberto Pascual", :male],
      ["Carmen", :female],
      ["Juan higuera", :male],
      ["Natalia Serrano Ruiz", :female],
      ["Andrea", :female],
      ["Francisco", :male],
      ["Ana", :female],
      ["Marta", :female],
      ["sara cacho orts", :female],
      ["Amalia  del pino", :female],
      ["Carla Pinar Gonzalez", :female],
      ["Alejandra Suarez", :female],
      ["Jaime Fernández", :male],
      ["silvia", :female],
      ["Pablo", :male],
      ["Lucas", :male],
      ["Sara", :female],
      ["Pepe Ortiz", :male],
      ["Barbara", :female],
      ["Antonio José González Guillén", :male],
      ["tamara", :female],
      ["Pedro Campoy", :male],
      ["mohamed ouass", :male],
      ["M del Ángel", :male],
      ["Elena", :female],
      ["Marta", :female],
      ["Gonzalo Machuca Aguado", :male],
      ["Gabriela", :female],
      ["Borja Hernando", :male],
      ["jaime galvez", :male],
      ["celia", :female],
      ["Carmen", :female],
      ["Delia", :female],
      ["Luis Feito Sancho", :male],
      ["mar", :female],
      ["Jose Maria", :male],
      ["Pablo Sánchez de Lamadrid", :male],
      ["Belén Zubiaga", :female],
      ["Borja", :male],
      ["Rafael Muñoz Marroig", :male],
      ["Marga", :female],
      ["Acosta", nil],
      ["Begoñe", :female],
      ["Gabriela", :female],
      ["Ernesto", :male],
      ["Jose", :male],
      ["María", :female],
      ["Inma Garcia", :female],
      ["natalia chairri", :female],
      ["macarena ruiz", :female],
      ["Laura", :female],
      ["01731365", nil],
      ["Carlos", :male],
      ["Ale", :male],
      ["Mary", :female],
      ["Jaime", :male],
      ["MARIA JOSE DORADO", :female],
      ["Jorge", :male],
      ["isabel", :female],
      ["Ana", :female],
      ["Gonzalo Pascual", :male],
      ["Cristina", :female],
      ["Juan Ruiz Toribio", :male],
      ["Carla Figueiras", :female],
      ["alma", :female],
      ["Jorge Crespo", :male],
      ["Daniela sohl", :female],
      ["Natalia Alarcon", :female],
      ["Elena losa", :female],
      ["María", :female],
      ["jorge", :male],
      ["Ana", :female],
      ["sandra", :female],
      ["Juanjo de Pablos", :male],
      ["Teresa", :female],
      ["Alberto", :male],
      ["Julia", :female],
      ["Iñaki", :male],
      ["Ignacio", :male],
      ["Teresa", :female],
      ["BORJA", :male],
      ["laura", :female],
      ["rafa", :male],
      ["ana", :female],
      ["beatriz", :female],
      ["Rodrigo", :male],
      ["Ignacio", :male],
      ["Jorge Aranda", :male],
      ["Iñaki", :male],
      ["Fermin", :male],
      ["Pedro", :male],
      ["Carlos", :male],
      ["BELEN CORREA", :female],
      ["Alicia Quesada", :female],
      ["Jordan Balmori", :male],
      ["ana", :female],
      ["Carlota Laseca", :female],
      ["Deborah", :female],
      ["Pablo", :male],
      ["Raul", :male],
      ["Begoña urarte", :female],
      ["Ricardo", :male],
      ["Ilse", :female],
      ["Maider Silva", :female],
      ["María Sancho", :female],
      ["Jorge", :male],
      ["María", :female],
      ["Ivan", :male],
      ["ana", :female],
      ["Julia Figueroa", :female],
      ["Raquel Rojo", :female],
      ["Gerar PiazZola", :male],
      ["elena", :female],
      ["Pablo", :male],
      ["Pablo", :male],
      ["Yolanda", :female],
      ["Adela Lopez Sanchez", :female],
      ["TERESA", :female],
      ["Diego Huarte", :male],
      ["Darío", :male],
      ["Clara perez pozuelo", :female],
      ["Mario", :male],
      ["Sebastian Torres Llosa", :male],
      ["miriam santos gonzalez-sierra", :female],
      ["Sergio Torrecillas", :male],
      ["Eider", :male],
      ["Javier", :male],
      ["rosa", :female],
      ["Guillermo", :male],
      ["Calala", nil],
      ["Aurora", :female],
      ["IGNC11", nil],
      ["Rocio", :female],
      ["sandra", :female],
      ["Gloria", :female],
      ["Diego", :male],
      ["Alejandro", :male],
      ["Lucía", :female],
      ["Maria", :female],
      ["Miquel Pons Martínez", :male],
      ["Jorge", :male],
      ["Juan", :male],
      ["Angela Ybarra", :female],
      ["rocio mazon", :female],
      ["Susana", :female],
      ["Julio babe", :male],
      ["Marcos", :male],
      ["Jaime", :male],
      ["Marta avellana", :female],
      ["Ainhoa", :female],
      ["Ana Corral", :female],
      ["Ignacio", :male],
      ["Manuel Pérez Fernández", :male],
      ["MARTA", :female],
      ["guillermo", :male],
      ["garsa", :female],
      ["Juan", :male],
      ["Monica", :female],
      ["Beatriz Prada", :female],
      ["Juan Pedro", :male],
      ["Clara", :female],
      ["Gonzalo", :male],
      ["loreto", :female],
      ["Pablo Aparicio", :male],
      ["Tomi", :male],
      ["Lucia", :female],
      ["Alvaro Erhardt", :male],
      ["Celeste Ruiz", :female],
      ["Irene", :female],
      ["maniel mateo", :male],
      ["Rocio Looez Estrada", :female],
      ["Maria Luisa", :female],
      ["Carmen", :female],
      ["Aurelio Escribano", :male],
      ["Camelia Ali", :female],
      ["Bego", :female],
      ["Patricia romero", :female],
      ["hector", :male],
      ["pilar rubio pastor", :female],
      ["Kelly", :female],
      ["Carolina Escribano Sanchez", :female],
      ["Arantxa", :female],
      ["marina porras", :female],
      ["sonsoles", :female],
      ["Nico garcia", :male],
      ["Miguel", :male],
      ["Jaime Eugui", :male],
      ["Armando", :male],
      ["Ana Navedo", :female],
      ["Marife Maroto Mena", :female],
      ["Laura", :female],
      ["Miriam", :female],
      ["Gaspar", :male],
      ["Fernando López Cantero", :male],
      ["Marie de Fontaines", :female],
      ["Belén Lera", :female],
      ["Paula", :female],
      ["Ignacio Montojo", :male],
      ["Mnuel Gomez", :male],
      ["Natalia millan", :female],
      ["lidia", :female],
      ["Sofia", :female],
      ["Trinidad Desongles", :female],
      ["Nacho Casariego", :male],
      ["Cristina", :female],
      ["carmen del rio", :female],
      ["Rosalía", :female],
      ["Jade Ruiz", :female],
      ["Patricia", :female],
      ["Blanca", :female],
      ["Josep", :male],
      ["yago", :male],
      ["Sofia", :female],
      ["M Carmen", :female],
      ["julio", :male],
      ["Luis", :male],
      ["Clara", :female],
      ["Marivi Urbina", :female],
      ["Aurora", :female],
      ["Pablo", :male],
      ["Félix coleto", :male],
      ["Jorge Crespo", :male],
      ["Ignacio", :male],
      ["Ricardo", :male],
      ["Ramón", :male],
      ["Paloma", :female],
      ["Silvia", :female],
      ["Loli", :female],
      ["Mateo", :male],
      ["Pedro", :male],
      ["Arturo", :male],
      ["Elisa", :female],
      ["Antonio", :male],
      ["Enrique", :male],
      ["Mercedes", :female],
      ["María", :female],
      ["jorge", :male],
      ["Maria", :female],
      ["Sonso moral", :female],
      ["Pilar Armelles", :female],
      ["Francisco", :male],
      ["alicia", :female],
      ["Ana", :female],
      ["Angeles", :female],
      ["Sebastián Pulido Florido", :male],
      ["alejandro", :male],
      ["Adriana", :female],
      ["Carmen", :female],
      ["Angel tejada", :male],
      ["Helena", :female],
      ["Sergi", :male],
      ["Ana Alvaro", :female],
      ["Carlos", :male],
      ["Pablo", :male],
      ["Javier Laguía Cassany", :male],
      ["Teresa", :female],
      ["Carlota Leal", :female],
      ["Macarena", :female],
      ["richi", :male],
      ["Nicolás Muñoz Román", :male],
      ["Fermin", :male],
      ["Carlos Aguilera", :male],
      ["Nacho", :male],
      ["Teresa", :female],
      ["fernando", :male],
      ["Alejandro Gutiérrez Menzinger", :male],
      ["michel", :male],
      ["Paula santos", :female],
      ["Carlos", :male],
      ["Celia Andrada", :female],
      ["Álvaro Baron argos", :male],
      ["Laura Manzano", :female],
      ["Paula Piqueras", :female],
      ["Valentina", :female],
      ["José Juan García Exposito", :male],
      ["Claudia", :female],
      ["tongas", nil],
      ["Gines", :male],
      ["carmen", :female],
      ["Sandra", :female],
      ["Marc Morera", :male],
      ["Leo Falcó", :male],
      ["Mireia Viadel", :female],
      ["Marta ruiz mayo", :female],
      ["ines", :female],
      ["Jose", :male],
      ["Cristina", :female],
      ["Mònica Pastor", :female],
      ["cecilia domínguez", :female],
      ["Blanca Laguna Reyes", :female],
      ["Matthoeu", :male],
      ["Alfonso", :male],
      ["blanca", :female],
      ["Alvaro", :male],
      ["lara", :female],
      ["Helena", :female],
      ["maria", :female],
      ["Pablo Vicente elvira", :male],
      ["SUSANA", :female],
      ["Ana Mateo Sanmartin", :female],
      ["Nacholopez", nil],
      ["Cristina", :female],
      ["Sonia Grandes", :female],
      ["Ana", :female],
      ["Blanca", :female],
      ["Omar García Ruiz", :male],
      ["John Chart", :male],
      ["José francisco", :male],
      ["jose luis bianchi", :male],
      ["Luis", :male],
      ["julillo98", nil],
      ["Maria Blanco", :female],
      ["María", :female],
      ["Jose", :male],
      ["Fernando Rincon Marenco", :male],
      ["Marisa Llobell", :female],
      ["Belén", :female],
      ["Esther", :female],
      ["Gonzalo ver varela", :male],
      ["Nacho", :male],
      ["Adriana", :female],
      ["Ángeles", :female],
      ["MIRIAM", :female],
      ["Julián", :male],
      ["Laura", :female],
      ["Laura", :female],
      ["Ludivina", :female],
      ["Marta", :female],
      ["Begoña Tellez Alvarez", :female],
      ["africa", :female],
      ["Jaime Hoyos", :male],
      ["Gonzalo", :male],
      ["Paloma Garcia", :female],
      ["Maria", :female],
      ["paloma", :female],
      ["Paloma", :female],
      ["Marta Vena", :female],
      ["Jaime Hoyos", :male],
      ["angela", :female],
      ["Nuria", :female],
      ["Adrián", :male],
      ["David", :male],
      ["Astrid Alvarez Gutiérrez", :female],
      ["katherine portorreal", :female],
      ["ana", :female],
      ["Enrique", :male],
      ["Jorge", :male],
      ["Carla", :female],
      ["Esther", :female],
      ["Ana", :female],
      ["Marta", :female],
      ["Marga", :female],
      ["María José Ferrer", :female],
      ["Natalia Zardoya Jiménez", :female],
      ["Gracia", :female],
      ["Jon Ander", :male],
      ["Jorge", :male],
      ["Corona", :female],
      ["José", :male],
      ["Daniela", :female],
      ["Alejandro", :male],
      ["alba", :female],
      ["melani", :female],
      ["MARINA AREIZAGA", :female],
      ["Lucia", :female],
      ["Luis pujades", :male],
      ["Carla", :female],
      ["mariafalava", nil],
      ["bdvbd", nil],
      ["Cristian", :male],
      ["Yago", :male],
      ["Ana", :female],
      ["Carmen", :female],
      ["Ángel Maurer", :male],
      ["Carmela", :female],
      ["Blanca", :female],
      ["Anastacia", :female],
      ["Andrea García López", :female],
      ["Carmela", :female],
      ["Carme garrote barberá", :female],
      ["imanol", :male],
      ["Alejandra Sedeño López", :female],
      ["Eva", :female],
      ["Cecilia", :female],
      ["Lydia", :female],
      ["Patricia Carpio", :female],
      ["Jose Javier", :male],
      ["fiona", :female],
      ["rocio", :female],
      ["Alicia Pérez", :female],
      ["Sergio Garcia", :male],
      ["Andrea", :female],
      ["Marta", :female],
      ["Adrián Muñoz Durán", :male],
      ["Ester", :female],
      ["Gonzalo", :male],
      ["Sofia Roca de Togores", :female],
      ["Diego González", :male],
      ["Pedro", :male],
      ["mario bonmati echevarria", :male],
      ["Cristina", :female],
      ["Carlos", :male],
      ["Maria", :female],
      ["Fernando", :male],
      ["Nabila", :female],
      ["Tania", :female],
      ["Natalia", :female],
      ["Alicia", :female],
      ["Miriam", :female],
      ["José Manuel", :male]].each do |name, sex|
      example = Ladyboy::Parser.new name
      [name, example.gender].must_equal     [name, sex]
    end
  end
end